# frozen_string_literal: true
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/api/label.proto

require 'google/protobuf'


descriptor_data = "\n\x16google/api/label.proto\x12\ngoogle.api\"\x9c\x01\n\x0fLabelDescriptor\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x39\n\nvalue_type\x18\x02 \x01(\x0e\x32%.google.api.LabelDescriptor.ValueType\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\",\n\tValueType\x12\n\n\x06STRING\x10\x00\x12\x08\n\x04\x42OOL\x10\x01\x12\t\n\x05INT64\x10\x02\x42\\\n\x0e\x63om.google.apiB\nLabelProtoP\x01Z5google.golang.org/genproto/googleapis/api/label;label\xa2\x02\x04GAPIb\x06proto3"

pool = Google::Protobuf::DescriptorPool.generated_pool

begin
  pool.add_serialized_file(descriptor_data)
rescue TypeError
  # Compatibility code: will be removed in the next major version.
  require 'google/protobuf/descriptor_pb'
  parsed = Google::Protobuf::FileDescriptorProto.decode(descriptor_data)
  parsed.clear_dependency
  serialized = parsed.class.encode(parsed)
  file = pool.add_serialized_file(serialized)
  warn "Warning: Protobuf detected an import path issue while loading generated file #{__FILE__}"
  imports = [
  ]
  imports.each do |type_name, expected_filename|
    import_file = pool.lookup(type_name).file_descriptor
    if import_file.name != expected_filename
      warn "- #{file.name} imports #{expected_filename}, but that import was loaded as #{import_file.name}"
    end
  end
  warn "Each proto file must use a consistent fully-qualified name."
  warn "This will become an error in the next major version."
end

module Google
  module Api
    LabelDescriptor = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("google.api.LabelDescriptor").msgclass
    LabelDescriptor::ValueType = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("google.api.LabelDescriptor.ValueType").enummodule
  end
end

#### Source proto file: google/api/label.proto ####
#
# // Copyright 2025 Google LLC
# //
# // Licensed under the Apache License, Version 2.0 (the "License");
# // you may not use this file except in compliance with the License.
# // You may obtain a copy of the License at
# //
# //     http://www.apache.org/licenses/LICENSE-2.0
# //
# // Unless required by applicable law or agreed to in writing, software
# // distributed under the License is distributed on an "AS IS" BASIS,
# // WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# // See the License for the specific language governing permissions and
# // limitations under the License.
#
# syntax = "proto3";
#
# package google.api;
#
# option go_package = "google.golang.org/genproto/googleapis/api/label;label";
# option java_multiple_files = true;
# option java_outer_classname = "LabelProto";
# option java_package = "com.google.api";
# option objc_class_prefix = "GAPI";
#
# // A description of a label.
# message LabelDescriptor {
#   // Value types that can be used as label values.
#   enum ValueType {
#     // A variable-length string. This is the default.
#     STRING = 0;
#
#     // Boolean; true or false.
#     BOOL = 1;
#
#     // A 64-bit signed integer.
#     INT64 = 2;
#   }
#
#   // The label key.
#   string key = 1;
#
#   // The type of data that can be assigned to the label.
#   ValueType value_type = 2;
#
#   // A human-readable description for the label.
#   string description = 3;
# }
