# frozen_string_literal: true
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/type/date.proto

require 'google/protobuf'


descriptor_data = "\n\x16google/type/date.proto\x12\x0bgoogle.type\"0\n\x04\x44\x61te\x12\x0c\n\x04year\x18\x01 \x01(\x05\x12\r\n\x05month\x18\x02 \x01(\x05\x12\x0b\n\x03\x64\x61y\x18\x03 \x01(\x05\x42]\n\x0f\x63om.google.typeB\tDateProtoP\x01Z4google.golang.org/genproto/googleapis/type/date;date\xf8\x01\x01\xa2\x02\x03GTPb\x06proto3"

pool = Google::Protobuf::DescriptorPool.generated_pool

begin
  pool.add_serialized_file(descriptor_data)
rescue TypeError
  # Compatibility code: will be removed in the next major version.
  require 'google/protobuf/descriptor_pb'
  parsed = Google::Protobuf::FileDescriptorProto.decode(descriptor_data)
  parsed.clear_dependency
  serialized = parsed.class.encode(parsed)
  file = pool.add_serialized_file(serialized)
  warn "Warning: Protobuf detected an import path issue while loading generated file #{__FILE__}"
  imports = [
  ]
  imports.each do |type_name, expected_filename|
    import_file = pool.lookup(type_name).file_descriptor
    if import_file.name != expected_filename
      warn "- #{file.name} imports #{expected_filename}, but that import was loaded as #{import_file.name}"
    end
  end
  warn "Each proto file must use a consistent fully-qualified name."
  warn "This will become an error in the next major version."
end

module Google
  module Type
    Date = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("google.type.Date").msgclass
  end
end

#### Source proto file: google/type/date.proto ####
#
# // Copyright 2025 Google LLC
# //
# // Licensed under the Apache License, Version 2.0 (the "License");
# // you may not use this file except in compliance with the License.
# // You may obtain a copy of the License at
# //
# //     http://www.apache.org/licenses/LICENSE-2.0
# //
# // Unless required by applicable law or agreed to in writing, software
# // distributed under the License is distributed on an "AS IS" BASIS,
# // WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# // See the License for the specific language governing permissions and
# // limitations under the License.
#
# syntax = "proto3";
#
# package google.type;
#
# option cc_enable_arenas = true;
# option go_package = "google.golang.org/genproto/googleapis/type/date;date";
# option java_multiple_files = true;
# option java_outer_classname = "DateProto";
# option java_package = "com.google.type";
# option objc_class_prefix = "GTP";
#
# // Represents a whole or partial calendar date, such as a birthday. The time of
# // day and time zone are either specified elsewhere or are insignificant. The
# // date is relative to the Gregorian Calendar. This can represent one of the
# // following:
# //
# // * A full date, with non-zero year, month, and day values
# // * A month and day value, with a zero year, such as an anniversary
# // * A year on its own, with zero month and day values
# // * A year and month value, with a zero day, such as a credit card expiration
# // date
# //
# // Related types are [google.type.TimeOfDay][google.type.TimeOfDay] and
# // `google.protobuf.Timestamp`.
# message Date {
#   // Year of the date. Must be from 1 to 9999, or 0 to specify a date without
#   // a year.
#   int32 year = 1;
#
#   // Month of a year. Must be from 1 to 12, or 0 to specify a year without a
#   // month and day.
#   int32 month = 2;
#
#   // Day of a month. Must be from 1 to 31 and valid for the year and month, or 0
#   // to specify a year by itself or a year and month where the day isn't
#   // significant.
#   int32 day = 3;
# }
